Index: trunk/psLib/src/image/psImage.h
===================================================================
--- trunk/psLib/src/image/psImage.h	(revision 4330)
+++ trunk/psLib/src/image/psImage.h	(revision 4409)
@@ -11,6 +11,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.58 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-21 03:01:37 $
+ *  @version $Revision: 1.59 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-28 20:17:52 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -132,9 +132,9 @@
 /** Create a string of the standard IRAF form '[x0:x1,y0:y1]' from a psRegion.
  *
  *  @return char*:  A new string representing the psRegion as text, or NULL
  *                  is not successful.
  */
-char* psRegionToString(
-    psRegion region                   ///< the psRegion to convert to a string
+psString psRegionToString(
+    const psRegion region              ///< the psRegion to convert to a string
 );
 
@@ -132,9 +132,9 @@
 /** Create a string of the standard IRAF form '[x0:x1,y0:y1]' from a psRegion.
  *
- *  @return char*:  A new string representing the psRegion as text, or NULL
+ *  @return psString:  A new string representing the psRegion as text, or NULL
  *                  is not successful.
  */
